@@ -6,8 +6,8 @@
 
 #pragma once
 
-#include "asn1/CVCertificateChain.h"
 #include "BaseCardCommand.h"
+#include "asn1/CVCertificateChain.h"
 
 class test_CardConnection;
 class test_DidAuthenticateEAC2Command;
@@ -19,26 +19,29 @@ class DidAuthenticateEAC2Command
 	: public BaseCardCommand
 {
 	Q_OBJECT
+	friend class ::test_CardConnection;
+	friend class ::test_DidAuthenticateEAC2Command;
 
 	private:
-		friend class ::test_CardConnection;
-		friend class ::test_DidAuthenticateEAC2Command;
 		CVCertificateChain mCvcChain;
 		QByteArray mEphemeralPublicKeyAsHex;
 		QByteArray mSignatureAsHex;
 		QByteArray mAuthenticatedAuxiliaryDataAsBinary;
+		QByteArray mPin;
 		QByteArray mEfCardSecurityAsHex;
 		QByteArray mNonceAsHex;
 		QByteArray mAuthTokenAsHex;
 
 		CardReturnCode putCertificateChain(const CVCertificateChain& pCvcChain);
-		CardReturnCode performTerminalAuthentication(const QByteArray& taProtocol,
-				const QByteArray& chr,
-				const QByteArray& auxiliaryData,
-				const QByteArray& compressedEphemeralPublicKey,
-				const QByteArray& signature);
+		CardReturnCode performTerminalAuthentication(const Oid& pTaProtocol,
+				const QByteArray& pChr,
+				const QByteArray& pAuxiliaryData,
+				const QByteArray& pCompressedEphemeralPublicKey,
+				const QByteArray& pSignature);
 		CardReturnCode performChipAuthentication(QSharedPointer<const ChipAuthenticationInfo> pChipAuthInfo,
-				const QByteArray& ephemeralPublicKey);
+				const QByteArray& pEphemeralPublicKey);
+
+		void internalExecuteSoftwareSmartCard();
 
 	protected:
 		void internalExecute() override;
@@ -47,7 +50,8 @@ class DidAuthenticateEAC2Command
 	public:
 		explicit DidAuthenticateEAC2Command(QSharedPointer<CardConnectionWorker> pCardConnectionWorker,
 				const CVCertificateChain& pCvcChain, const QByteArray& pEphemeralPublicKeyAsHex,
-				const QByteArray& pSignatureAsHex, const QByteArray& pAuthenticatedAuxiliaryDataAsBinary);
+				const QByteArray& pSignatureAsHex, const QByteArray& pAuthenticatedAuxiliaryDataAsBinary,
+				const QByteArray& pPin);
 
 
 		[[nodiscard]] const QByteArray& getEfCardSecurityAsHex() const
