@@ -2,9 +2,10 @@
  * \copyright Copyright (c) 2014-2022 Governikus GmbH & Co. KG, Germany
  */
 
+#include "apdu/SecureMessagingCommand.h"
+#include "apdu/SecureMessagingResponse.h"
 #include "asn1/ASN1Util.h"
 #include "pace/SecureMessaging.h"
-#include "SecureMessagingResponse.h"
 
 #include <QLoggingCategory>
 #include <QtEndian>
@@ -17,26 +18,13 @@ Q_DECLARE_LOGGING_CATEGORY(card)
 Q_DECLARE_LOGGING_CATEGORY(secure)
 
 
-const char ISO_LEADING_PAD_BYTE = char(0x80);
+const char ISO_LEADING_PAD_BYTE = static_cast<char>(0x80);
 const char ISO_PAD_BYTE = 0x00;
 
 
-namespace governikus
-{
-
-ASN1_ITEM_TEMPLATE(SM_PROTECTED_LE) =
-			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_CONTEXT, 0x17, SM_PROTECTED_LE, ASN1_OCTET_STRING)
-ASN1_ITEM_TEMPLATE_END(SM_PROTECTED_LE)
-IMPLEMENT_ASN1_FUNCTIONS(SM_PROTECTED_LE)
-IMPLEMENT_ASN1_OBJECT(SM_PROTECTED_LE)
-
-
-}  // namespace governikus
-
-
-SecureMessaging::SecureMessaging(const QByteArray& pPaceAlgorithm, const QByteArray& pEncKey, const QByteArray& pMacKey)
-	: mCipher(pPaceAlgorithm, pEncKey)
-	, mCipherMac(pPaceAlgorithm, pMacKey)
+SecureMessaging::SecureMessaging(const SecurityProtocol& pSecurityProtocol, const QByteArray& pEncKey, const QByteArray& pMacKey)
+	: mCipher(pSecurityProtocol, pEncKey)
+	, mCipherMac(pSecurityProtocol, pMacKey)
 	, mSendSequenceCounter(0)
 {
 	qCDebug(secure) << "Encryption key:" << pEncKey.toHex();
@@ -91,12 +79,18 @@ CommandApdu SecureMessaging::encrypt(const CommandApdu& pCommandApdu)
 	if (!isInitialized())
 	{
 		qCCritical(card) << "SecureMessaging not successfully initialized";
-		return CommandApdu(QByteArray());
+		return CommandApdu();
 	}
 
 	++mSendSequenceCounter;
 
-	qCDebug(secure) << "Plain CommandApdu:" << pCommandApdu.getBuffer().toHex();
+	if (pCommandApdu.isEmpty())
+	{
+		qCCritical(card) << "CommandApdu is empty";
+		return CommandApdu();
+	}
+
+	qCDebug(secure) << "Plain CommandApdu:" << pCommandApdu;
 
 	QByteArray formattedEncryptedData;
 	if (!pCommandApdu.getData().isEmpty())
@@ -126,14 +120,53 @@ CommandApdu SecureMessaging::encrypt(const CommandApdu& pCommandApdu)
 }
 
 
+CommandApdu SecureMessaging::decrypt(const CommandApdu& pEncryptedCommandApdu)
+{
+	if (!isInitialized())
+	{
+		qCCritical(card) << "SecureMessaging not successfully initialized";
+		return CommandApdu();
+	}
+
+	++mSendSequenceCounter;
+
+	const SecureMessagingCommand secureCommand(pEncryptedCommandApdu);
+	if (!secureCommand.isValid())
+	{
+		qCCritical(card) << "Secured CommandApdu is invalid";
+		return CommandApdu();
+	}
+
+	if (createMac(pEncryptedCommandApdu.getHeaderBytes(), secureCommand.getEncryptedDataObjectEncoded(), secureCommand.getExpectedLengthObjectEncoded()).mid(2) != secureCommand.getMac())
+	{
+		qCCritical(card) << "MAC on secured CommandApdu does not match";
+		return CommandApdu();
+	}
+
+	QByteArray decryptedData;
+	if (!secureCommand.getEncryptedData().isEmpty())
+	{
+		mCipher.setIv(getEncryptedIv());
+		QByteArray paddedDecryptedData = mCipher.decrypt(secureCommand.getEncryptedData());
+		decryptedData = unpadFromCipherBlockSize(paddedDecryptedData);
+	}
+
+	CommandApdu encrypted(pEncryptedCommandApdu.getHeaderBytes(), decryptedData, secureCommand.getExpectedLength());
+	const QByteArray macToCheck = decryptedData.right(10);
+	if (macToCheck.size() != 10 || !macToCheck.startsWith(QByteArray::fromHex("8E08")))
+	{
+		encrypted.setSecureMessaging(false);
+	}
+
+	return encrypted;
+}
+
+
 QByteArray SecureMessaging::createSecuredHeader(const CommandApdu& pCommandApdu) const
 {
-	QByteArray securedHeader;
-	securedHeader += static_cast<char>((pCommandApdu.getCLA() & 0xF0) | CommandApdu::CLA_SECURE_MESSAGING);
-	securedHeader += pCommandApdu.getINS();
-	securedHeader += pCommandApdu.getP1();
-	securedHeader += pCommandApdu.getP2();
-	return securedHeader;
+	CommandApdu apdu(pCommandApdu.getHeaderBytes());
+	apdu.setSecureMessaging(true);
+	return apdu.getHeaderBytes();
 }
 
 
@@ -144,9 +177,9 @@ QByteArray SecureMessaging::createSecuredLe(int pLe) const
 	{
 		if (pLe > CommandApdu::SHORT_MAX_LE)
 		{
-			buffer += static_cast<char>(pLe >> 0x08 & 0xff);
+			buffer += static_cast<char>(pLe >> 0x08 & 0xFF);
 		}
-		buffer += static_cast<char>(pLe >> 0x00 & 0xff);
+		buffer += static_cast<char>(pLe >> 0x00 & 0xFF);
 	}
 	return buffer;
 }
@@ -199,6 +232,41 @@ QByteArray SecureMessaging::getEncryptedIv()
 }
 
 
+ResponseApdu SecureMessaging::encrypt(const ResponseApdu& pResponseApdu)
+{
+	if (!isInitialized())
+	{
+		qCCritical(card) << "SecureMessaging not successfully initialized";
+		return ResponseApdu();
+	}
+
+	++mSendSequenceCounter;
+
+	QByteArray formattedEncryptedData;
+	if (!pResponseApdu.getData().isEmpty())
+	{
+		QByteArray paddedResponseData = padToCipherBlockSize(pResponseApdu.getData());
+		mCipher.setIv(getEncryptedIv());
+		QByteArray encryptedData = mCipher.encrypt(paddedResponseData).prepend(0x01);
+
+		auto encryptedDataObject = newObject<SM_ENCRYPTED_DATA>();
+		Asn1OctetStringUtil::setValue(encryptedData, encryptedDataObject.data());
+		formattedEncryptedData = encodeObject(encryptedDataObject.data());
+	}
+
+	const QByteArray status = pResponseApdu.getStatusBytes();
+	auto formattedStatus = newObject<SM_PROCESSING_STATUS>();
+	Asn1OctetStringUtil::setValue(status, formattedStatus.data());
+	formattedEncryptedData += encodeObject(formattedStatus.data());
+
+	QByteArray mac = mCipherMac.generate(getSendSequenceCounter() + padToCipherBlockSize(formattedEncryptedData));
+	auto macObject = newObject<SM_CHECKSUM>();
+	Asn1OctetStringUtil::setValue(mac, macObject.data());
+
+	return ResponseApdu(formattedEncryptedData + encodeObject(macObject.data()) + status);
+}
+
+
 ResponseApdu SecureMessaging::decrypt(const ResponseApdu& pEncryptedResponseApdu)
 {
 	if (!isInitialized())
@@ -209,12 +277,13 @@ ResponseApdu SecureMessaging::decrypt(const ResponseApdu& pEncryptedResponseApdu
 
 	++mSendSequenceCounter;
 
-	SecureMessagingResponse secureResponse(pEncryptedResponseApdu.getBuffer());
-	if (secureResponse.isInvalid())
+	SecureMessagingResponse secureResponse(pEncryptedResponseApdu);
+	if (!secureResponse.isValid())
 	{
 		return ResponseApdu();
 	}
-	if (secureResponse.getSecuredStatusCode() != secureResponse.getReturnCode())
+
+	if (secureResponse.getSecuredStatusCode() != pEncryptedResponseApdu.getStatusCode())
 	{
 		qCCritical(card) << "SW1SW2 on secured ResponseApdu does not match";
 		return ResponseApdu();
@@ -243,6 +312,6 @@ ResponseApdu SecureMessaging::decrypt(const ResponseApdu& pEncryptedResponseApdu
 	}
 
 	const ResponseApdu response(decryptedData + secureResponse.getSecuredStatusCodeBytes());
-	qCDebug(secure) << "Plain ResponseApdu:" << response.getBuffer().toHex();
+	qCDebug(secure) << "Plain ResponseApdu:" << response;
 	return response;
 }
