@@ -8,9 +8,9 @@
 #include <QtGlobal>
 
 #if defined(Q_OS_ANDROID)
-	#include <QAndroidJniEnvironment>
-	#include <QAndroidJniObject>
-	#include <QtAndroid>
+	#include <QCoreApplication>
+	#include <QJniEnvironment>
+	#include <QJniObject>
 #endif
 
 Q_DECLARE_LOGGING_CATEGORY(network)
@@ -18,34 +18,41 @@ Q_DECLARE_LOGGING_CATEGORY(network)
 using namespace governikus;
 
 
+#if defined(Q_OS_ANDROID)
 MulticastLock::MulticastLock()
 {
-#if defined(Q_OS_ANDROID)
 	invokeJniMethod("acquire");
-#endif
 }
 
 
 MulticastLock::~MulticastLock()
 {
-#if defined(Q_OS_ANDROID)
 	invokeJniMethod("release");
-#endif
 }
 
 
+#else
+MulticastLock::MulticastLock() = default;
+
+
+MulticastLock::~MulticastLock() = default;
+
+
+#endif
+
+
 void MulticastLock::invokeJniMethod(const char* const pMethodName)
 {
 #if defined(Q_OS_ANDROID)
-	QAndroidJniEnvironment env;
-	const QAndroidJniObject context(QtAndroid::androidContext());
+	QJniEnvironment env;
+	const QJniObject context(QNativeInterface::QAndroidApplication::context());
 	if (!context.isValid())
 	{
 		qCCritical(network) << "Cannot determine android context.";
 		return;
 	}
 
-	QAndroidJniObject::callStaticMethod<void>("com/governikus/ausweisapp2/MulticastLockJniBridgeUtil",
+	QJniObject::callStaticMethod<void>("com/governikus/ausweisapp2/MulticastLockJniBridgeUtil",
 			pMethodName,
 			"(Landroid/content/Context;)V",
 			context.object<jobject>());
