@@ -5,6 +5,8 @@
 
 #include "AbstractSettings.h"
 
+#include "Backup.h"
+
 #include <QCoreApplication>
 
 using namespace governikus;
@@ -19,6 +21,13 @@ AbstractSettings::AbstractSettings()
 }
 
 
+void AbstractSettings::save(const QSharedPointer<QSettings>& pSettings)
+{
+	pSettings->sync();
+	Backup::disable(pSettings);
+}
+
+
 QSharedPointer<QSettings> AbstractSettings::getStore(const QString& pFilename, QSettings::Format pFormat)
 {
 #ifndef QT_NO_DEBUG
