@@ -4,6 +4,10 @@
 
 #include "controller/WorkflowController.h"
 
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
+	#include "ReaderManager.h"
+#endif
+
 #include <QDebug>
 
 using namespace governikus;
@@ -16,11 +20,6 @@ WorkflowController::WorkflowController(const QSharedPointer<WorkflowContext>& pC
 }
 
 
-WorkflowController::~WorkflowController()
-{
-}
-
-
 void WorkflowController::run()
 {
 	mStateMachine.start();
