@@ -6,14 +6,7 @@
 
 using namespace governikus;
 
-Eac2InputType::Eac2InputType()
-{
-}
-
-
-Eac2InputType::~Eac2InputType()
-{
-}
+Eac2InputType::~Eac2InputType() = default;
 
 
 const QString& Eac2InputType::getSignature() const
@@ -22,18 +15,12 @@ const QString& Eac2InputType::getSignature() const
 }
 
 
-const QVector<QSharedPointer<const CVCertificate> >& Eac2InputType::getCvCertificates() const
+const QVector<QSharedPointer<const CVCertificate>>& Eac2InputType::getCvCertificates() const
 {
 	return mCvCertificates;
 }
 
 
-const QByteArrayList& Eac2InputType::getCvCertificatesAsBinary() const
-{
-	return mCvCertificatesAsBinary;
-}
-
-
 const QString& Eac2InputType::getEphemeralPublicKey() const
 {
 	return mEphemeralPublicKey;
@@ -56,9 +43,3 @@ void Eac2InputType::appendCvcert(const QSharedPointer<const CVCertificate>& pCer
 {
 	mCvCertificates += pCert;
 }
-
-
-void Eac2InputType::appendCvcertAsBinary(const QByteArray& pCvcertAsBinary)
-{
-	mCvCertificatesAsBinary += pCvcertAsBinary;
-}
